<?php

namespace HCM\FPA\ObrigacaoLegal\Demonstrativo_Eletronico\santander\registro;

use HCM\FPA\ObrigacaoLegal\Demonstrativo_Eletronico\RegistroHolerite;
use HCM\Util\DateUtil;

class Registro1HoleriteSantander extends RegistroHolerite{

    const REGISTRO_1 = '1';

    private $_estrutura;
    private $_codConvenioBanco;
    private $_pessoa;
    private $_vinculo;


    public function geraRegistro1(){
        $this->_geraRegistro();
    }


    private function _geraRegistro(){
        // Bloco 01 | 0001-0001 | Tipo de registro = 1.
        $this->atribuiDado(self::REGISTRO_1, 1);

        // Bloco 02 | 0002-0021 | Número do convênio de empresa com o banco.
        $this->atribuiDado($this->_codConvenioBanco, 20, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 03 | 0022-0041 | Matrícula do funcionário.
        $this->atribuiDado($this->_vinculo->getCdmatricula(), 20, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);
        
        // Bloco 04 | 0042-0052 | CPF.
        $this->atribuiDado($this->_pessoa->historico->getNrcpfpessoa(), 11, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 05 | 0053-0099 | Nome do Funcionário.
        $this->atribuiDado($this->_vinculo->getNmvinculom(), 47, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 06 | 0100-0103 | Código do banco do funcionario.
        $this->atribuiDado($this->_pessoa->banco, 4, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 07 | 0104-0107 | Código da agência do funcionário.
        $aux = $this->_pessoa->agencia;
        if(strlen($aux) > 4)
            $aux = substr($this->_pessoa->agencia, 1, 4);
        $this->atribuiDado($aux, 4, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 08 | 0108-0119 | Conta corrente do funcionário.
        $this->atribuiDado($this->_pessoa->contaCorrente, 12, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 09 | 0120-0154 | Cabeçalho Débito.
        // @todo Holerite
        $this->atribuiDado('HISTORICO DE DEBITOS', 35, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 10 | 0155-0189 | Cabeçalho Crédito.
        // @todo Holerite
        $this->atribuiDado('HISTORICO DE CREDITOS', 35, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 11 | 0190-0224 | Cabeçalho Líquido.
        // @todo Holerite
        $this->atribuiDado('LIQUIDO A RECEBER', 35, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 12 | 0225-0225 | Bloqueio de visualização e impressão do Holerite.
        // @todo Holerite
        //$this->atribuiDado('S', 1, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);
        $this->atribuiDado(' ',1, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 13 | 0226-0240 | Livre (Preencher com espaços).
        $this->atribuiDado(self::CARACTER_BRANCO, 15, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 14 | 0241-0252 | Livre (Preencher com zeros).
        $this->atribuiDado(self::CARACTER_ZERO, 12, self::CARACTER_ZERO, self::PREENCHE_ESQUERDA);

        // Bloco 15 | 0253-0267 | Cargo do funcionário.
        $this->atribuiDado($this->_vinculo->cargo, 15, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 16 | 0268-0269 | Indicador de matrícula - Possui mais de uma matrícula.
        $this->atribuiDado('N', 1, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);

        // Bloco 17 | 0270-0400 | Livre (Preencher com espaços).
        $this->atribuiDado(self::CARACTER_BRANCO, 132, self::CARACTER_BRANCO, self::PREENCHE_DIREITA);
    }


    public function setEstrutura($estrutura)
    {
        $this->_estrutura = $estrutura;
    }

    public function setCodConvenioBanco($codConvenioBanco)
    {
        $this->_codConvenioBanco = $codConvenioBanco;
    }

    public function setPessoa($pessoa)
    {
        $this->_pessoa = $pessoa;
    }

    public function setVinculo($vinculo)
    {
        $this->_vinculo = $vinculo;
    }


}