<?php

namespace HCM\Geral\Logic\Apolo;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\TkDI;
use HCM\Util\MsgCalculo;
use HCM\Util\Util;
use Zeedhi\Framework\Session\Session;
use HCM\Geral\Entity\EstruturamEntity;
use HCM\Geral\Entity\GpepessoaEntity;
use HCM\Geral\Services\ESocialService;
use HCM\Util\Mail\Mail;
use Teknisa\Libs\Util\SMTP;
use HCM\Geral\Services\EnviarEmailService;

class EmailAniversariantesLogic {


    private $hcmParameters;
    private $jenkins;
    private $entityManager;
    private $orgsEnvio = array();

    public function __construct(){
        $this->entityManager = \Setforms2\Shared\Registry::getEntityManager();
        $session = new Session();
        $this->hcmParameters = new HCMParameters($session, FPA::getTempDirectory(), null, null);
    }
    
    public function start(){
        $aniversariantes = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->_retornaAniversariantes();
        $nrorgAtual = null;
        if($aniversariantes){
            foreach($aniversariantes as $aniversariante){
                if($nrorgAtual != $aniversariante['NRORG']){
                    $this->setHcmParameters($aniversariante['NRORG']);
                }
                
                $mailService = $this->hcmParameters->returnParamsSmtp();
                $content = $assunto = null;
    
                if($aniversariante['CDCOMUNICAPARC']){
                    if($aniversariante['TITULO_NIVERNASC']){
                        $this->sendEmail($mailService, $aniversariante['CDCOMUNICAPARC'], $aniversariante, $aniversariante['TITULO_NIVERNASC'], $aniversariante['CORPO_NIVERNASC']);
                    }
                    
                    if($aniversariante['TITULO_NIVEREMPR']){
                        $this->sendEmail($mailService, $aniversariante['CDCOMUNICAPARC'], $aniversariante, $aniversariante['TITULO_NIVEREMPR'], $aniversariante['CORPO_NIVEREMPR']); 
                    }
                }
                $nrorgAtual = $aniversariante['NRORG'];
            }
        }
        
        $this->percorreVencimentos();
    }
    
    private function percorreVencimentos(){
        $esoParametros = $this->entityManager->getRepository(Repositories::ESO_PARAMETRO)->getEsoParametro(false);
        
        //Separa registros da Eso parametro por organização.
        foreach($esoParametros as $key => $esoParametro){
            $registrosParametrosPorOrg[$esoParametro['NRORG']] = $esoParametro;
        }
        $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
        
        //Percorre Organizações
        foreach ($registrosParametrosPorOrg as $nrorg => $parametros) {
        
            $this->setHcmParameters($nrorg);
            $mailService = $this->hcmParameters->returnParamsSmtp();
            $params = array('P_NRORG' => $nrorg, 'NMVINCULOM' => null, 'NMORGANIZACAO' => null);
            $enviaGestor = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->buscavalor($nrorg, 0, DateUtil::getDataAtual(), 'ENVIA_NOTIFICACAO_GESTOR');
            
            //FERIAS
            $qryFeriasVencer = $this->entityManager->getRepository(Repositories::GER_VERIFICACAO)->getQueryFeriasVencer3Meses();
            $resultFerias = $db->fetchAll($qryFeriasVencer, $params);
            $msgsFerias = [];
            if($resultFerias){
                foreach($resultFerias as $row){
                    $vinculo = $row['VINCULO'];
                    $iniAquisicao = $row['INICIO_AQUISICAO'];
                    $fimAquisicao = $row['FIM_AQUISICAO'];
                    $dataLimite = $row['DATA_LIMITE'];
                    $msgsFerias[$row['NRESTRUTURAM']]['MSG'] .= '<br> O vínculo '.$vinculo.' possui periodos de ferias a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                    $msgsFerias[$row['NRESTRUTURAM']]['EMAILRESPONSAVEL'] = $row['CDCOMUNICAPARC'];
                    $msgsFerias[$row['TOTAL']]['MSG'] .= '<br> O vínculo '.$vinculo.' possui periodos de ferias a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                }
                foreach($msgsFerias as $msgFerias){
                    if($enviaGestor && $msgFerias['EMAILRESPONSAVEL']){
                        $this->sendEmail($mailService, $msgFerias['EMAILRESPONSAVEL'], $params, 'Notificação Férias a Vencer', $msgFerias['MSG']);
                    }
                }
            }
            
            //CONTRATO A VENCER
            $qryContratoVencer = $this->entityManager->getRepository(Repositories::GER_VERIFICACAO)->getQueryContratoAVencer10Dias();
            $resultContrato = $db->fetchAll($qryContratoVencer, $params);
            $msgsContrato = [];
            if($resultContrato){
                foreach($resultContrato as $row){
                    $vinculo = $row['VINCULO'];
                    $dataLimite = $row['FIM_CONTRATO'];
                    $msgsContrato[$row['NRESTRUTURAM']]['MSG'] .= '<br>  O vínculo '.$vinculo.' possui contrato a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                    $msgsContrato[$row['NRESTRUTURAM']]['EMAILRESPONSAVEL'] = $row['CDCOMUNICAPARC'];
                    $msgsContrato[$row['TOTAL']]['MSG'] .= '<br>  O vínculo '.$vinculo.' possui contrato a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                }
                foreach($msgsContrato as $msgContrato){
                    if($enviaGestor && $msgContrato['EMAILRESPONSAVEL']){
                        $this->sendEmail($mailService, $msgContrato['EMAILRESPONSAVEL'], $params, 'Notificação Contrato a Vencer', $msgContrato['MSG']);
                    }
                }
            }
            
            //MATERNIDADE
            $qryLicencaMaternidadeVencer = $this->entityManager->getRepository(Repositories::GER_VERIFICACAO)->getQueryLicencaMaternidadeVencer10Dias();
            $resultMaternidade = $db->fetchAll($qryLicencaMaternidadeVencer, $params);
            $msgsMaternidade = [];
            if($resultMaternidade){
                foreach($resultMaternidade as $row){
                    $vinculo = $row['VINCULO'];
                    $dataLimite = $row['DATA_FINAL'];
                    $msgsMaternidade[$row['NRESTRUTURAM']]['MSG'] .= '<br> O vínculo '.$vinculo.' possui maternidade a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                    $msgsMaternidade[$row['NRESTRUTURAM']]['EMAILRESPONSAVEL'] = $row['CDCOMUNICAPARC'];
                    $msgsMaternidade[$row['TOTAL']]['MSG'] .= '<br> O vínculo '.$vinculo.' possui maternidade a vencer, data limite '.$dataLimite.' <br> '.PHP_EOL;
                }
                foreach($msgsMaternidade as $msgMaternidade){
                    if($enviaGestor && $msgMaternidade['EMAILRESPONSAVEL']){
                        $this->sendEmail($mailService, $msgMaternidade['EMAILRESPONSAVEL'], $params, 'Notificação Maternidade a Vencer', $msgMaternidade['MSG']);
                    }
                }
            }
            
            $emails = explode(';', $parametros['DSEMAILENVIO']);
            $enviaDp = $this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->buscavalor($nrorg, 0, DateUtil::getDataAtual(), 'ENVIA_NOTIFICACAO_DP');
            if($enviaDp){
                foreach ($emails as $email) {
                    $this->sendEmail($mailService, $email, $params, 'Notificação Férias a Vencer', $msgsFerias[$row['TOTAL']]['MSG']);
                    $this->sendEmail($mailService, $email, $params, 'Notificação Contrato a Vencer', $msgsContrato[$row['TOTAL']]['MSG']);
                    $this->sendEmail($mailService, $email, $params, 'Notificação Maternidade a Vencer', $msgsMaternidade[$row['TOTAL']]['MSG']);
                }
            }
        }
    }
    
    private function sendEmail($mailService, $email, $aniversariante, $titulo = null, $corpo = null){
        $assunto = $titulo;
        $content = $this->template($corpo);
        $nmdestinatario = $aniversariante['NMVINCULOM'];
        $nmremetente   = $aniversariante['NMORGANIZACAO'];
                
        $mailService->newEmail(
            $email, //e-mail destinatário
            str_replace("[COLABORADOR]", $nmdestinatario, $content), //texto
            str_replace("[COLABORADOR]", $nmdestinatario, $assunto), //assunto    
            $nmdestinatario, //nome operador
            $nmremetente,
            null,
            null,
            true
        );
    }
    
    public function setHcmParameters($nrorg){
        
        $nrtpestrutlegal = 1;
        $nrtpestrutgeren = 6;
        $paramOrg = $this->entityManager->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => $nrorg));
        
        if($paramOrg){
            $nrtpestrutlegal = $paramOrg->getNrtpestrutlegal();
            $nrtpestrutgeren = $paramOrg->getNrtpestrutgeren();
        }
    
        $paramsHCM = array(
        "cdoperador"        => 1,
        "CDOPERADOR"        => 1,
        "nmoperador"        => null,
        "nrestruttrab"      => null,
        "nrorgpadrao"       => 0,
        "nrorg"             => $nrorg,
        "nrorgtrab"         => $nrorg,
        "dtmescompetenc"    => DateUtil::setDay(DateUtil::getDataAtual(), 1)->format('d/m/Y'),
        "dtmescompetencdiacorrente" => DateUtil::setDay(DateUtil::getDataAtual(), 1)->format('d/m/Y'),
        "nrtipoestrutlegal" => $nrtpestrutlegal,
        "nrtipoestrutgeren" => $nrtpestrutgeren,
        "idambientesal"     => 'REAL',
        "nrocorrecal"       => 1,
        "nrtpmodalidcal"    => 1,
        "nrtpmodalidsal"    => 1,
        "dataatual"         => DateUtil::getDataAtual(),
        "dtultimodiames"    => DateUtil::getUltimoDiaDoMes(DateUtil::getDataAtual())->format('d/m/Y'),
        "dtultimodiacompetencia" => DateUtil::getUltimoDiaDoMes(DateUtil::getDataAtual())->format('d/m/Y'),
        );
        
        foreach ($paramsHCM as $key => $value) {
            $this->hcmParameters->set($key, $value);
        }
        
    }
    
    
    public function template($corpo_msg){
       
       $corpo = <<<HTML
<table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee" style="background-color: #eeeeee"> 
    <tbody> 
        <tr> 
            <td> 
                <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="0274BA" style="background-color: #0274ba ; text-align: center"> 
                    <tbody> 
                        <tr> 
                            <td> 
                                <table border="0" align="center" width="540" cellpadding="0" cellspacing="0"> 
                                    <tbody> 
                                        <tr> 
                                            <td align="center" valign="middle"> 
                                                <table border="0" align="middle" cellpadding="0" cellspacing="0" style="border-collapse: collapse"> 
                                                    <tbody> 
                                                        <tr> 
                                                            <td align="center" valign="middle"> 
                                                                <div style="color: #ffffff ; font-size: 25px ; padding: 35px ; font-family: &quot;verdana&quot; , sans-serif ; line-height: 24px">NOTIFICAÇÃO HCM
                                                                </div> 
                                                                <div style="color: #ffffff ; font-size: 16px ; font-family: &quot;verdana&quot; , sans-serif">
                                                                </div> 
                                                                <div style="color: #ffffff ; font-size: 16px ; font-family: &quot;verdana&quot; , sans-serif">
                                                                </div> 
                                                                <div style="color: #ffffff ; font-size: 16px ; font-family: &quot;verdana&quot; , sans-serif">
                                                                </div> 
                                                            </td> 
                                                        </tr> 
                                                    </tbody> 
                                                </table> 
                                            </td> 
                                        </tr> 
                                    </tbody> 
                                </table> 
                            </td> 
                        </tr> 
                    </tbody> 
                </table> 
            </td> 
        </tr> 
    </tbody> 
</table> 
<div> 
$corpo_msg
</b> 
</div> 
<table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee"> 
    <tbody> 
        <tr> 
            <td align="center"> 
                <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="ffffff">
                    <div> 
                        <tbody> 
                            <tr> 
                                <td> 
                                    <table border="0" align="center" width="540" cellpadding="0" cellspacing="0"> 
                                        <tbody> 
                                            <tr> 
                                                <td align="left" style="color: #39434b ; font-size: 20px ; font-family: &quot;verdana&quot; , sans-serif">  
                                                    
                                                        <div>
                                                            <img src="https://www.teknisa.com/emails/img/rodape_3.png">
                                                              </div>
                                                                    </div> 
                                                                </td> 
                                                            </tr> 
                                                            <tr> 
                                                                <td height="10" style="font-size: 10px ; line-height: 10px"> 
                                                                </td> 
                                                            </tr> 
                                                        </tbody> 
                                                    </table> 
                                                </td> 
                                            </tr> 
                                        </tbody> 
                                    </div>
                                    <div>
                                        <br>
                                        </div>
                                    </table> 
                                </td> 
                            </tr> 
                        </tbody> 
                    </table> 
                    <table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee"> 
                        <tbody> 
                            <tr> 
                                <td> 
                                    <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="#d8d8d8"> 
                                        <tbody> 
                                            <tr>
                                            </tr> 
                                            <tr>
                                            </tr> 
                                            <tr> 
                                                <td height="20" style="font-size: 20px ; line-height: 20px ; display: table"> 
                                                </td> 
                                            </tr> 
                                        </tbody> 
                                    </table> 
                                </td> 
                            </tr> 
                        </tbody> 
                    </table>
HTML;
    
        return $corpo;
    }
    
    
}