<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class ESocialItensCadTabRepository {

    protected  $connection;

    public function __construct(Connection $connection, EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }

    /**
     * @param $params Row esoEnvioCadastros
     * @return array
     */
    public function getItensParaEnvioS1000($params) {
        try {
            // Só envia itens se for CNPJ Matriz ou se for outro tipo de inscrição
            $idMatriz = isset($params['IDMATRIZ']) ? $params['IDMATRIZ'] : 'S';
            
            if ($idMatriz == 'S') {
                $sql = <<<SQL
SELECT EH.NRESTRUTURAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       EH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                    AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = EH.NRORG)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EH.NRESTRUTURAM AS NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1000'
               JOIN ESTRUTURAH EH ON EH.NRORG = EC.NRORG
                                 AND EH.NRESTRUTURAM = EC.NRCHAVE
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EH.NRESTRUTURAM) ENV ON ENV.NRCHAVE = EH.NRESTRUTURAM
 WHERE EM.NRORG = :P_NRORG
   AND EM.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL
   AND EM.NRESTRUTURAM = :P_NRESTRUTURAM
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC OR EM.DTFIMVIGENCIA IS NULL)
SQL;
                $params = array(
                    "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                    "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                    "P_NRTIPOESTRUTLEGAL" => $this->hcmParameters->getTipoEstruturaLegalOrg(),
                    "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                    "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                );
                return $this->connection->fetchAll($sql, $params);
            } else {
                throw new \Exception('HCM09000_ESO_EVENTO_MATRIZ_ERROR');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1005($params) {
        try {
            $sql = <<<SQL
SELECT EH.NRESTRUTURAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       EH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                    AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = EH.NRORG)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EH.NRESTRUTURAM AS NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1005'
               JOIN ESTRUTURAH EH ON EH.NRORG = EC.NRORG
                                 AND EH.NRESTRUTURAM = EC.NRCHAVE
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EH.NRESTRUTURAM) ENV ON ENV.NRCHAVE = EH.NRESTRUTURAM
 WHERE EM.NRORG = :P_NRORG
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND EM.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL
   AND EM.NRESTRUTURAM = :P_NRESTRUTURAM
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_NRTIPOESTRUTLEGAL" => $this->hcmParameters->getTipoEstruturaLegalOrg(),
                "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
            );
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1010($params) {
        try {
            // Só envia itens se for CNPJ Matriz ou se for outro tipo de inscrição
            $idMatriz = isset($params['IDMATRIZ']) ? $params['IDMATRIZ'] : 'S';
            if ($idMatriz == 'S') {
                $sql = <<<SQL
SELECT EH.NREVENTOM as NRCHAVE,
       TM.NRTIPOMOVIMENT as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       EH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM FPA_EVENTOM EM
  JOIN FPA_EVENTOH EH ON EH.NRORG = EM.NRORG
                     AND EH.NREVENTOM = EM.NREVENTOM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM FPA_EVENTOH H1
                                               WHERE H1.NREVENTOM = EH.NREVENTOM
                                                 AND H1.NRORG = EH.NRORG
                                                 AND H1.DTMESCOMPETENC <= LAST_DAY(:P_DTMESCOMPETENC))
  /*Tipos de Movimento sao usados como tabela*/
  JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT IN (1,2,4,10,19,22)
  /*Natureza da Rubrica*/
  JOIN NATUREZARUBRICA NR ON NR.NRNATURUBR = EH.NRNATURUBR
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, EC.NRTABELA, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1010'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE, EC.NRTABELA) ENV ON ENV.NRCHAVE = EH.NREVENTOM
                                                AND ENV.NRTABELA = TM.NRTIPOMOVIMENT
 WHERE (EM.NRORG = :P_NRORG OR EM.NRORG = 0)
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND (EM.NREVENTOM = :P_NREVENTOM OR :P_NREVENTOM IS NULL)
   AND (TM.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT OR INSTR(','||:P_NRTIPOMOVIMENT||',', ','||TM.NRTIPOMOVIMENT||',') > 0 OR :P_NRTIPOMOVIMENT IS NULL)
 ORDER BY EH.NREVENTOM, TM.NRTIPOMOVIMENT, EH.DTMESCOMPETENC
SQL;
                $params = array(
                    "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                    "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                    "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                    "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                    "P_NREVENTOM" => isset($params['NREVENTOM']) ? $params['NREVENTOM'] : null,
                    "P_NRTIPOMOVIMENT" => isset($params['NRTIPOMOVIMENT']) ? $params['NRTIPOMOVIMENT'] : null,
                );
                
                $return = $this->connection->fetchAll($sql, $params);
                return $return;
            } else {
                throw new \Exception('HCM09000_ESO_EVENTO_MATRIZ_ERROR');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1020($parameters) {
        try {
            $sql = <<<SQL
/*Própria estrutura legal*/
SELECT EH.NRESTRUTURAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       EH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                     AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                               WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND H1.NRORG = EH.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1020'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = EH.NRESTRUTURAM
 WHERE EM.NRORG = :P_NRORG
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND EM.NRESTRUTURAM = :P_NRESTRUTURAM
  
UNION ALL
/*Tomadores abaixo da estrutura legal*/
SELECT DISTINCT EH.NRESTRUTURAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       EH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                     AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                               WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND H1.NRORG = EH.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*Estrutura Gerencial - Hierarquia Tomador/Gerencial*/
  JOIN HIERARQUIAORG HG ON HG.NRORG = EM.NRORG
                       AND HG.NRESTRUTURAMSUP = EM.NRESTRUTURAM
  JOIN TIPOHIERARQORG TG ON (TG.NRORG = HG.NRORG OR TG.NRORG = 0)
                        AND TG.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
                        AND TG.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                        AND TG.NRTIPOHIERARQORG = HG.NRTIPOHIERARQORG
  /*Empregador - Estrutura Legal - Hieraquia Legal/Gerencial*/
  JOIN HIERARQUIAORG HE ON HE.NRORG = HG.NRORG
                       AND HE.NRESTRUTURAMREL = HG.NRESTRUTURAMREL
                       AND HE.NRESTRUTURAMSUP = :P_NRESTRUTURAM
  JOIN TIPOHIERARQORG TE ON (TE.NRORG = EM.NRORG OR TE.NRORG = 0)
                        AND TE.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                        AND TE.NRTIPOESTRUTSUP = :P_NRTIPOESTRUTLEGAL
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1020'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = EH.NRESTRUTURAM
 WHERE EM.NRORG = :P_NRORG
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND EM.NRTIPOESTRUTURA = NVL(:P_NRTIPOESTRUTOMADOR, 7)
   AND (EM.NRESTRUTURAM = :P_NRESTRUTOMADOR OR :P_NRESTRUTOMADOR IS NULL)
   AND NOT EXISTS (SELECT 1
                     FROM ESO_ENVIOCADASTROS EC
                     JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                       AND EV.NMEVENTO = 'S-1020'
                     /*VERIFICA EMPRESAS DO MESMO GRUPO - CNPJ RAIZ*/
                     JOIN ESTRUTURAH EVH ON EVH.NRORG = EC.NRORG
                                        AND EVH.NRESTRUTURAM = EC.NRESTRUTURAM
                                        AND SUBSTR(REPLACE(REPLACE(REPLACE(EVH.CDCNPJESTRUT,'.'),'/'),'-'),1,8) = SUBSTR(REPLACE(REPLACE(REPLACE(:P_CDCNPJEMPREGADOR,'.'),'/'),'-'),1,8)
                                        AND EVH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                                   WHERE H1.NRORG = EVH.NRORG
                                                                     AND H1.NRESTRUTURAM = EVH.NRESTRUTURAM
                                                                     AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                    WHERE EC.NRORG = :P_NRORG
                      AND EC.NRCHAVE = :P_NRESTRUTOMADOR
                      AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                      AND (EC.IDSTATUS = 'P' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                      AND EC.NRENVIOEXCL IS NULL /*QUE NAO FOI EXCLUIDO*/
                      AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                      AND EC.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
 ORDER BY 1,4
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_NRTIPOESTRUTLEGAL" => $this->hcmParameters->getTipoEstruturaLegalOrg(),
                "P_NRTIPOESTRUTGEREN" => $this->hcmParameters->getTipoEstruturaGerencialOrg(),
                "P_NRTIPOESTRUTOMADOR" => $this->hcmParameters->getTipoEstruturaTomadorOrg(),
                "P_NRESTRUTURAM" => isset($parameters['NRESTRUTURAM']) ? $parameters['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($parameters['NRTPAMBIENTE']) ? $parameters['NRTPAMBIENTE'] : null,
                "P_NRESTRUTOMADOR" => isset($parameters['NRESTRUTTOMAD']) ? $parameters['NRESTRUTTOMAD'] : null,
                "P_CDCNPJEMPREGADOR" => isset($parameters['CDCNPJEMPREGADOR']) ? $parameters['CDCNPJEMPREGADOR'] : null
            );
           
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1030($params) {
        try {
            // Só envia itens se for CNPJ Matriz ou se for outro tipo de inscrição
            $idMatriz = isset($params['IDMATRIZ']) ? $params['IDMATRIZ'] : 'S';
            if ($idMatriz == 'S') {
                $sql = <<<SQL
SELECT OH.NROCUPACAOM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       OH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM GPE_OCUPACAOM OM
  JOIN GPE_OCUPACAOH OH ON OH.NRORG = OM.NRORG
                     AND OH.NROCUPACAOM = OM.NROCUPACAOM
                     AND OH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH H1
                                               WHERE H1.NROCUPACAOM = OM.NROCUPACAOM
                                                 AND H1.NRORG = OM.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1030'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = OM.NROCUPACAOM
 WHERE OM.NRORG = :P_NRORG
   AND OM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (OM.DTFIMVIGENCIA IS NULL OR OM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND (OM.NROCUPACAOM = :P_NROCUPACAOM OR :P_NROCUPACAOM IS NULL)
 ORDER BY 1,4
SQL;
                $params = array(
                    "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                    "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                    "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                    "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                    "P_NROCUPACAOM" => isset($params['NROCUPACAOM']) ? $params['NROCUPACAOM'] : null,
                );
                return $this->connection->fetchAll($sql, $params);
            } else {
                throw new \Exception('HCM09000_ESO_EVENTO_MATRIZ_ERROR');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1040($params) {
        try {
            // Só envia itens se for CNPJ Matriz ou se for outro tipo de inscrição
            $idMatriz = isset($params['IDMATRIZ']) ? $params['IDMATRIZ'] : 'S';
            if ($idMatriz == 'S') {
                $sql = <<<SQL
SELECT OH.NROCUPACAOM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       OH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM GPE_OCUPACAOM OM
  JOIN GPE_OCUPACAOH OH ON OH.NRORG = OM.NRORG
                     AND OH.NROCUPACAOM = OM.NROCUPACAOM
                     AND OH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH H1
                                               WHERE H1.NROCUPACAOM = OM.NROCUPACAOM
                                                 AND H1.NRORG = OM.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1040'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = OM.NROCUPACAOM
 WHERE OM.NRORG = :P_NRORG
   AND OM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (OM.DTFIMVIGENCIA IS NULL OR OM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND (OM.NROCUPACAOM = :P_NROCUPACAOM OR :P_NROCUPACAOM IS NULL)
 ORDER BY 1,4
SQL;
                $params = array(
                    "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                    "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                    "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                    "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                    "P_NROCUPACAOM" => isset($params['NROCUPACAOM']) ? $params['NROCUPACAOM'] : null,
                );
                return $this->connection->fetchAll($sql, $params);
            } else {
                throw new \Exception('HCM09000_ESO_EVENTO_MATRIZ_ERROR');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1050($params) {
        try {
            // Só envia itens se for CNPJ Matriz ou se for outro tipo de inscrição
            $idMatriz = isset($params['IDMATRIZ']) ? $params['IDMATRIZ'] : 'S';
            if ($idMatriz == 'S') {
                $sql = <<<SQL
SELECT HH.NRHORDIAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       HH.DTMESCOMPETENC as DTMESCOMPETENC
  FROM GPE_HORDIAM HM
  JOIN GPE_HORDIAH HH ON HH.NRORG = HM.NRORG
                     AND HH.NRHORDIAM = HM.NRHORDIAM
                     AND HH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_HORDIAH H1
                                               WHERE H1.NRHORDIAM = HH.NRHORDIAM
                                                 AND H1.NRORG = HH.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1050'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = HH.NRHORDIAM
 WHERE (HM.NRORG = :P_NRORG OR HM.NRORG = 0)
   AND HH.IDTIPOHORARIO <> 'F'
   AND HM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (HM.DTFIMVIGENCIA IS NULL OR HM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND (HM.NRHORDIAM = :P_NRHORDIAM OR :P_NRHORDIAM IS NULL)
 ORDER BY 1,4
SQL;
                $params = array(
                    "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                    "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                    "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                    "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                    "P_NRHORDIAM" => isset($params['NRHORDIAM']) ? $params['NRHORDIAM'] : null,
                );
                return $this->connection->fetchAll($sql, $params);
            } else {
                throw new \Exception('HCM09000_ESO_EVENTO_MATRIZ_ERROR');
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1060($params) {
        try {
            $sql = <<<SQL
SELECT EH.NRESTRUTURAM as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       NVL(EM.DTESOCIAL,EH.DTMESCOMPETENC) as DTMESCOMPETENC
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                     AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                               WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                 AND H1.NRORG = EH.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                     /*Somente estruturas gerencias que possuem vinculos ativos*/
                     AND EXISTS (SELECT 1
                                   FROM GPE_VINCULOM VM
                                   JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                                                       AND VH.NRVINCULOM = VM.NRVINCULOM
                                                       AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
                                                       AND VH.NRESTRUTGEREN = EH.NRESTRUTURAM
                                                       AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                                                 WHERE H1.NRORG = VH.NRORG
                                                                                   AND H1.NRVINCULOM = VH.NRVINCULOM
                                                                                   AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                                                   AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                                  WHERE VM.NRORG = EH.NRORG
                                    AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
                                    AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= :P_DTMESCOMPETENC))
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1060'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRORG = EH.NRORG AND ENV.NRCHAVE = EH.NRESTRUTURAM
 WHERE EM.NRORG = :P_NRORG
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND EM.NRTIPOESTRUTURA = :P_NRTIPOESTRUTGEREN
   AND (EM.NRESTRUTURAM = :P_NRESTRUTGEREN OR :P_NRESTRUTGEREN IS NULL)
 ORDER BY 1,4
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_NRTIPOESTRUTGEREN" => $this->hcmParameters->getTipoEstruturaGerencialOrg(),
                "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                "P_NRESTRUTGEREN" => isset($params['NRESTRUTGEREN']) ? $params['NRESTRUTGEREN'] : null,
            );
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensParaEnvioS1070($params) {
        try {
            $sql = <<<SQL
SELECT PR.NRPROCESSADMJUD as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       PR.DTESOCIAL as DTMESCOMPETENC
  FROM GPE_PROCESSADMJUD PR
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1070'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = PR.NRPROCESSADMJUD
 WHERE PR.NRORG = :P_NRORG
   AND PR.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (PR.DTFIMVIGENCIA IS NULL OR PR.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND PR.NRESTRUTURAM = :P_NRESTRUTURAM
 ORDER BY 1
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
            );
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

}