<?php
/**
 * Created by PhpStorm.
 * User: felipesantos
 * Date: 21/09/2016
 * Time: 11:14
 */

namespace HCM\SST\Services;

use Doctrine\ORM\EntityManager;
use HCM\SST\Repository\HistoricoepiRepository;
use HCM\Util\FPA;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;

class ProgEntregaEPIService {

    const Alfabetica = 'ALFABETICA';
    const Data       = 'DATA_ADMISSAO';
    const Matricula  = 'MATRICULA';
    const Estrutura  = 'ESTRUTURA';

    protected $entityManager;
    protected $hcmParameters;

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, FPA $fpa, HistoricoepiRepository $historicoepiRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->historicoepiRepository = $historicoepiRepository;
    }

    public function getCriterioFromOrdem($ordem) {
        switch($ordem){
            case self::Alfabetica:
                $criterio = 'NMVINCULOM';
                break;
            case self::Data:
                $criterio = 'DTADMISSAOVINC';
                break;
            case self::Matricula:
                $criterio = 'CDMATRICULA';
                break;
            case self::Estrutura:
                $criterio = 'ESTRUTURA';
                break;
            default:
                $criterio = '';
                break;
        }
        return $criterio;
    }

    public function getSimulacao($dsordem, $dsinicio, $dsfim, $qtminatendmedio, $qtatendentrepi, $qthrdiaentrepi, $dtinicial, $dtfinal) {
        try {
            $dtmescompetenc = $this->hcmParameters->getDtCompetencia();
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $criterio = $this->getCriterioFromOrdem($dsordem);

            return $this->historicoepiRepository->getSimulacaoEntregaEpi($criterio, $dsinicio, $dsfim, $dtinicial, $dtfinal, $qtminatendmedio, $qtatendentrepi, $qthrdiaentrepi, $dtmescompetenc, $nrorg);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function gravar($dsordem, $dsinicio, $dsfim, $qtminatendmedio, $qtatendentrepi, $qthrdiaentrepi, $dtinicial, $dtfinal) {
        try {
            $dtmescompetenc = $this->hcmParameters->getDtCompetencia();
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $criterio = $this->getCriterioFromOrdem($dsordem);

            $histEpiLinhas = $this->historicoepiRepository->getDadosGravarHistoricoEpi($criterio, $dsinicio, $dsfim, $dtinicial, $dtfinal, $qtminatendmedio, $qtatendentrepi, $qthrdiaentrepi, $dtmescompetenc, $nrorg);

            if (!empty($histEpiLinhas)) {
                foreach ($histEpiLinhas as $histEpi) {
                    \Folha\Logic\Epi\ProgramacaoEntrega::gravarHistoricoEpi($histEpi);
                }
            } else {
                throw new \Exception(Messages::HCM05000_SST_PROGENTREPI_DADOS_NOT_FOUND_ERROR, Messages::ERROR_MESSAGE_CODE);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
}