/*
***********************************************************************************
****    Procedure para calculo do demonstrativo de resultado operacional
*************************************************************************************

Criado em  : 03/2018
       Por : Jefferson Gouvea

Descricao:

          - Com base nos dados parametrizados para a unidade realiza apuracao do
            resultado operacional da mesma, grava em tabelas especificas a fim de
            possibilitar a geracao de relatorios gerenciais a partir de dados
            previamente calculados.

  Procedure APURAC_INVENTARIOROP

  IM - Implantacao de Estoque
  AJ - Ajuste de Estoque
  II - Inventario Inicial
  IF - Inventario Final

*/

CREATE OR REPLACE PROCEDURE APURAC_INVENTARIOROP(
   P_CDFILIAL       FILIAL.CDFILIAL%TYPE,
   P_FILIALPAR      FILIAL.CDFILIAL%TYPE,
   P_DTINICIAL      IN DATE,
   P_DTFINAL        IN DATE, 
   P_NRROPFILIAL    IN VARCHAR,
   P_CDFILISUBGR    IN VARCHAR)
IS
   V_NRTIPOCUSTO    NUMBER;
   V_IDINVINICROP   VARCHAR2(01);
   V_IDINVFINAROP   VARCHAR2(01);
   V_NRSEQINVENROP  VARCHAR2(10);
   V_CDGRUPPROD     VARCHAR2(10);
   V_IDIMPLANTROP   VARCHAR2(01);
   V_IDAJUSTEROP    VARCHAR2(01);
   V_CDPRODFIN      VARCHAR2(20);
   V_CDPRODINI      VARCHAR2(20);
   V_NRMOVIESTQ     VARCHAR2(20);
   V_CDFILCENTPME   VARCHAR2(04);
   V_NRSEQINVENTROP NUMBER;  
   V_POSGRUPPROD    VARCHAR2(10);
   V_POSUBGRUPPROD  VARCHAR2(10);
BEGIN
   BEGIN
      SELECT TO_NUMBER(NVL(PF.CDTIPCUSTEST,'3'))
        INTO V_NRTIPOCUSTO
        FROM PARAMFILIAL PF, PARAMGERAL P
       WHERE PF.CDFILIAL = P_CDFILIAL;
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       V_NRTIPOCUSTO := '3';
   END;

   BEGIN
      SELECT P.IDINVINICROP, P.IDINVFINAROP, P.CDGRUPPROD, IDIMPLANTROP, IDAJUSTEROP
        INTO V_IDINVINICROP, V_IDINVFINAROP, V_CDGRUPPROD, V_IDIMPLANTROP, V_IDAJUSTEROP
        FROM PARFILIALROP P
       WHERE P.CDFILIAL = P_FILIALPAR;
   EXCEPTION
     WHEN NO_DATA_FOUND THEN BEGIN
       V_IDINVINICROP  := NULL;  V_IDIMPLANTROP := NULL;
       V_IDINVFINAROP  := NULL;  V_IDAJUSTEROP  := NULL;
       V_CDGRUPPROD    := NULL;
     END;
   END;

   BEGIN
      SELECT CDFILCENTPME
        INTO V_CDFILCENTPME
        FROM FILIAL
       WHERE CDFILIAL = P_CDFILIAL;
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       V_CDFILCENTPME := NULL;
   END;

   IF V_IDINVINICROP = 'S' THEN
      V_POSGRUPPROD   := NULL;
      V_POSUBGRUPPROD := NULL;
      IF V_NRTIPOCUSTO IN (40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,57,58,59,60,61,62) THEN

         FOR C_INVINICIAL IN (SELECT P.CDPRODUTO, P.QTESTDIACON,
                                     NVL(CUSTO_PRODUTO(P.CDFILIAL, P.CDPRODUTO, V_NRTIPOCUSTO, P_DTINICIAL-1, SYSDATE),0) * P.QTESTDIACON AS VRESTDIACON,
                                     PR.CDARVPROD
                                FROM POSESTCONS P, PRODUTO PR
                               WHERE P.CDFILIAL = P_CDFILIAL
                                 AND (P.QTESTDIACON <> 0 OR P.VRESTDIACON <> 0)
                                 AND P.DTPOSESTCON = (SELECT MAX(DTPOSESTCON)
                                                        FROM POSESTCONS C
                                                       WHERE C.CDFILIAL = P_CDFILIAL
                                                         AND C.CDPRODUTO = P.CDPRODUTO
                                                         AND C.DTPOSESTCON <= P_DTINICIAL)
                                 AND PR.CDPRODUTO = P.CDPRODUTO) LOOP
            BEGIN
               SELECT N.CDGRUPPROD, N.CDSUBGRPROD
                 INTO V_POSGRUPPROD, V_POSUBGRUPPROD
                 FROM PRODUTO P, NVSUBGRPROD N
                WHERE P.CDPRODUTO = N.CDPRODUTO
                  AND N.CDFILISUBGR = P_CDFILISUBGR
                  AND N.CDGRUPPROD = V_CDGRUPPROD
                  AND C_INVINICIAL.CDARVPROD LIKE N.CDPRODUTO||'%';
            EXCEPTION
              WHEN NO_DATA_FOUND THEN BEGIN
                  V_POSGRUPPROD := NULL;
                  V_POSUBGRUPPROD := NULL;
              END;
            END;

            IF V_POSGRUPPROD IS NOT NULL THEN
               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);

               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, V_POSGRUPPROD, V_POSUBGRUPPROD,
                            'INV_INICIAL', C_INVINICIAL.VRESTDIACON, V_CDFILCENTPME, P_DTINICIAL, SYSDATE,
                            C_INVINICIAL.QTESTDIACON);
            END IF;
         END LOOP;
      ELSE
         FOR C_INVINICIAL IN (SELECT B.CDPRODUTO, B.QTESTOQDIA AS QTESTDIACON,
                                     NVL(CUSTO_PRODUTO_LCEST(B.CDFILIAL,B.CDPRODUTO, V_NRTIPOCUSTO,P_DTINICIAL - 1, SYSDATE,B.CDALMOXARIFE,B.CDLOCALESTOQ,
                                     B.NRLOTEESTQ,B.NRSUBLOTE),0) * B.QTESTOQDIA AS VRESTDIACON, PR.CDARVPROD
                                FROM POSESTDIA B, PRODUTO PR
                               WHERE B.CDFILIAL = P_CDFILIAL
                                 AND B.QTESTOQDIA <> 0
                                 AND B.DTPOSIESTQ = (SELECT MAX(P.DTPOSIESTQ)
                                                       FROM POSESTDIA P
                                                      WHERE P.CDFILIAL = P_CDFILIAL
                                                        AND P.CDPRODUTO = B.CDPRODUTO
                                                        AND P.CDALMOXARIFE = B.CDALMOXARIFE
                                                        AND P.CDLOCALESTOQ = B.CDLOCALESTOQ
                                                        AND P.NRLOTEESTQ = B.NRLOTEESTQ
                                                        AND P.NRSUBLOTE = B.NRSUBLOTE
                                                        AND P.DTPOSIESTQ <= P_DTINICIAL)
                                 AND PR.CDPRODUTO = B.CDPRODUTO) LOOP

            BEGIN
               SELECT N.CDGRUPPROD, N.CDSUBGRPROD
                 INTO V_POSGRUPPROD, V_POSUBGRUPPROD
                 FROM PRODUTO P, NVSUBGRPROD N
                WHERE P.CDPRODUTO = N.CDPRODUTO
                  AND N.CDFILISUBGR = P_CDFILISUBGR
                  AND N.CDGRUPPROD = V_CDGRUPPROD
                  AND C_INVINICIAL.CDARVPROD LIKE N.CDPRODUTO||'%';
            EXCEPTION
              WHEN NO_DATA_FOUND THEN BEGIN
                  V_POSGRUPPROD := NULL;
                  V_POSUBGRUPPROD := NULL;
              END;
            END;

            IF V_POSGRUPPROD IS NOT NULL THEN
               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);

               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, V_POSGRUPPROD, V_POSUBGRUPPROD,
                            'INV_INICIAL', C_INVINICIAL.VRESTDIACON, V_CDFILCENTPME, P_DTINICIAL, SYSDATE,
                            C_INVINICIAL.QTESTDIACON);
            END IF;
         END LOOP;
      END IF;
   END IF;

   IF V_IDINVFINAROP = 'S' THEN
      V_POSGRUPPROD   := NULL;
      V_POSUBGRUPPROD := NULL;

      IF V_NRTIPOCUSTO IN (40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,57,58,59,60,61,62) THEN
         FOR C_INVFINAL IN (SELECT P.CDPRODUTO, P.QTESTDIACON,
                                   NVL(CUSTO_PRODUTO(P.CDFILIAL, P.CDPRODUTO, V_NRTIPOCUSTO, P_DTINICIAL, SYSDATE),0) * P.QTESTDIACON AS VRESTDIACON,
                                   PR.CDARVPROD
                              FROM POSESTCONS P, PRODUTO PR
                             WHERE P.CDFILIAL = P_CDFILIAL
                               AND (P.QTESTDIACON <> 0 OR P.VRESTDIACON <> 0)
                               AND P.DTPOSESTCON = (SELECT MAX(DTPOSESTCON)
                                                      FROM POSESTCONS C
                                                     WHERE C.CDFILIAL = P_CDFILIAL
                                                       AND C.CDPRODUTO = P.CDPRODUTO
                                                       AND C.DTPOSESTCON <= P_DTINICIAL+1)
                               AND PR.CDPRODUTO = P.CDPRODUTO) LOOP
            BEGIN
               SELECT N.CDGRUPPROD, N.CDSUBGRPROD
                 INTO V_POSGRUPPROD, V_POSUBGRUPPROD
                 FROM PRODUTO P, NVSUBGRPROD N
                WHERE P.CDPRODUTO = N.CDPRODUTO
                  AND N.CDFILISUBGR = P_CDFILISUBGR
                  AND N.CDGRUPPROD = V_CDGRUPPROD
                  AND C_INVFINAL.CDARVPROD LIKE N.CDPRODUTO||'%';
            EXCEPTION
              WHEN NO_DATA_FOUND THEN BEGIN
                 V_POSGRUPPROD := NULL;
                 V_POSUBGRUPPROD := NULL;
              END;
            END;

            IF V_POSGRUPPROD IS NOT NULL THEN
               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);

               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, V_POSGRUPPROD, V_POSUBGRUPPROD,
                            'INV_FINAL', C_INVFINAL.VRESTDIACON, V_CDFILCENTPME, P_DTINICIAL, SYSDATE,
                            C_INVFINAL.QTESTDIACON);
            END IF;
         END LOOP;
      ELSE
         FOR C_INVFINAL IN (SELECT B.CDPRODUTO, B.QTESTOQDIA AS QTESTDIACON,
                                   NVL(CUSTO_PRODUTO_LCEST(B.CDFILIAL,B.CDPRODUTO, V_NRTIPOCUSTO, P_DTINICIAL, SYSDATE,B.CDALMOXARIFE,B.CDLOCALESTOQ,
                                   B.NRLOTEESTQ,B.NRSUBLOTE),0) * B.QTESTOQDIA AS VRESTDIACON, PR.CDARVPROD
                              FROM POSESTDIA B, PRODUTO PR
                             WHERE B.CDFILIAL = P_CDFILIAL
                               AND B.QTESTOQDIA <> 0
                               AND B.DTPOSIESTQ = (SELECT MAX(P.DTPOSIESTQ)
                                                     FROM POSESTDIA P
                                                    WHERE P.CDFILIAL = P_CDFILIAL
                                                      AND P.CDPRODUTO = B.CDPRODUTO
                                                      AND P.CDALMOXARIFE = B.CDALMOXARIFE
                                                      AND P.CDLOCALESTOQ = B.CDLOCALESTOQ
                                                      AND P.NRLOTEESTQ = B.NRLOTEESTQ
                                                      AND P.NRSUBLOTE = B.NRSUBLOTE
                                                      AND P.DTPOSIESTQ <= P_DTINICIAL + 1)
                               AND PR.CDPRODUTO = B.CDPRODUTO) LOOP
            BEGIN
               SELECT N.CDGRUPPROD, N.CDSUBGRPROD
                 INTO V_POSGRUPPROD, V_POSUBGRUPPROD
                 FROM PRODUTO P,NVSUBGRPROD N
                WHERE P.CDPRODUTO = N.CDPRODUTO
                  AND N.CDFILISUBGR = P_CDFILISUBGR
                  AND N.CDGRUPPROD = V_CDGRUPPROD
                  AND C_INVFINAL.CDARVPROD LIKE N.CDPRODUTO||'%';
            EXCEPTION
              WHEN NO_DATA_FOUND THEN BEGIN
                  V_POSGRUPPROD := NULL;
                  V_POSUBGRUPPROD := NULL;
              END;
            END;

            IF V_POSGRUPPROD IS NOT NULL THEN
               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);

               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, V_POSGRUPPROD, V_POSUBGRUPPROD,
                            'INV_FINAL', C_INVFINAL.VRESTDIACON, V_CDFILCENTPME, P_DTINICIAL, SYSDATE,
                            C_INVFINAL.QTESTDIACON);
            END IF;
         END LOOP;
      END IF;
   END IF;

   /* IMPLANTACAO E AJUSTE */
   IF ((V_IDIMPLANTROP = 'S' OR V_IDAJUSTEROP = 'S')) AND (TRUNC(P_DTINICIAL) = FIRST_DAY(TRUNC(P_DTFINAL))) THEN
      SELECT MAX(P.CDARVPROD) AS CDPRODFIN, MIN(P.CDARVPROD) AS CDPRODINI
        INTO V_CDPRODFIN, V_CDPRODINI
        FROM PRODUTO P INNER JOIN ITLANCTOEST I ON I.CDPRODMOVI = P.CDPRODUTO
       WHERE I.CDFILIMOVI = P_CDFILIAL
         AND I.IDTIPOMOVI IN ('0','1')
         AND TRUNC(I.DTLANCMOVI) BETWEEN P_DTINICIAL AND P_DTFINAL;
         
      IF V_CDPRODFIN IS NOT NULL THEN
         SELECT LPAD(ABS(ROUND(DBMS_RANDOM.VALUE(9999,9999999999))),10,'0')
           INTO V_NRMOVIESTQ
           FROM DUAL;

         FOR C_MOVIMENTACAO IN (SELECT CDFILIMOVI, CDALMOXARIFE, CDLOCALESTOQ
                                  FROM ITLANCTOEST
                                 WHERE CDFILIMOVI = P_CDFILIAL
                                   AND DTLANCMOVI BETWEEN P_DTINICIAL AND P_DTFINAL
                                   AND IDTIPOMOVI IN ('1','0')
                                   AND CDPRODUTO BETWEEN V_CDPRODINI AND V_CDPRODFIN
                                 GROUP BY CDFILIMOVI, CDALMOXARIFE, CDLOCALESTOQ) LOOP

            MOVIMENTACAO_ESTOQUE(C_MOVIMENTACAO.CDFILIMOVI, C_MOVIMENTACAO.CDALMOXARIFE, C_MOVIMENTACAO.CDLOCALESTOQ,NULL, 1,
                                 P_DTINICIAL,P_DTFINAL, V_CDPRODINI, V_CDPRODFIN, 3, 1, V_NRMOVIESTQ, 'N', 'N', 'N');
         END LOOP;

         IF V_IDIMPLANTROP = 'S' THEN
            FOR C_IMPLANTACAO IN (SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, TRUNC(R.DTLANCMOVIEST) DTLANCMOVIEST, SUM(QTLANCAMENTO) QTLANCAMENTO,
                                         SUM(VRDIFECUST) VRDIFECUST
                                    FROM RELAT_MOVIEST R INNER JOIN PRODUTO P
                                                                 ON R.CDPRODMOVIEST = P.CDARVPROD
                                                         INNER JOIN (SELECT B.CDPRODUTO, A.CDGRUPPROD, A.CDSUBGRPROD, A.CDFILISUBGR
                                                                       FROM PRODUTO B INNER JOIN PRODUTO C ON B.CDPRODUTO = C.CDPRODUTO
                                                                                      INNER JOIN (SELECT P.CDARVPROD AS CDPRODUTO, N.CDGRUPPROD,
                                                                                                         N.CDSUBGRPROD, N.CDFILISUBGR
                                                                                                    FROM PRODUTO P,NVSUBGRPROD N
                                                                                                   WHERE P.CDPRODUTO   = N.CDPRODUTO
                                                                                                     AND N.CDFILISUBGR = P_CDFILISUBGR
                                                                                                     AND N.CDGRUPPROD  = V_CDGRUPPROD) A
                                                                                              ON C.CDARVPROD LIKE A.CDPRODUTO||'%'
                                                                      WHERE A.CDFILISUBGR = P_CDFILISUBGR
                                                                        AND A.CDGRUPPROD = V_CDGRUPPROD
                                                                      ORDER BY B.CDARVPROD) AN
                                                                 ON P.CDPRODUTO = AN.CDPRODUTO
                                                         INNER JOIN SUBGRPRODFIL SG
                                                                 ON AN.CDFILISUBGR = SG.CDFILISUBGR
                                                                AND AN.CDGRUPPROD = SG.CDGRUPPROD
                                                                AND AN.CDSUBGRPROD = SG.CDSUBGRPROD
                                   WHERE R.CDFILIMOVIEST = P_CDFILIAL
                                     AND R.NRRELATMOVI = V_NRMOVIESTQ
                                     AND TRUNC(R.DTLANCMOVIEST) BETWEEN P_DTINICIAL AND P_DTFINAL
                                     AND SG.CDFILISUBGR = P_CDFILISUBGR
                                     AND SG.CDGRUPPROD = V_CDGRUPPROD
                                     AND R.IDTIPOMOVIEST = '0'
                                   GROUP BY DTLANCMOVIEST, AN.CDGRUPPROD, AN.CDSUBGRPROD
                                   ORDER BY DTLANCMOVIEST, AN.CDSUBGRPROD, AN.CDGRUPPROD) LOOP

               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);
            
               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, C_IMPLANTACAO.CDGRUPPROD, C_IMPLANTACAO.CDSUBGRPROD,
                            'IMPLANTACAO', C_IMPLANTACAO.VRDIFECUST, V_CDFILCENTPME, C_IMPLANTACAO.DTLANCMOVIEST, SYSDATE,
                            C_IMPLANTACAO.QTLANCAMENTO);
            END LOOP;
         END IF;
         IF V_IDAJUSTEROP = 'S' THEN
            FOR C_AJUSTE IN (SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, TRUNC(DTLANCMOVIEST) DTLANCMOVIEST, SUM(QTLANCAMENTO) QTLANCAMENTO,
                                    SUM(VRDIFECUST) VRDIFECUST
                               FROM RELAT_MOVIEST R INNER JOIN PRODUTO  P ON R.CDPRODMOVIEST = P.CDARVPROD
                                                    INNER JOIN (SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR
                                                                  FROM PRODUTO B INNER JOIN PRODUTO C
                                                                                         ON B.CDPRODUTO = C.CDPRODUTO
                                                                                 INNER JOIN (SELECT P.CDARVPROD AS CDPRODUTO, N.CDGRUPPROD,
                                                                                                    N.CDSUBGRPROD, N.CDFILISUBGR
                                                                                               FROM PRODUTO P INNER JOIN NVSUBGRPROD N
                                                                                                                      ON P.CDPRODUTO = N.CDPRODUTO
                                                                                              WHERE N.CDFILISUBGR = P_CDFILISUBGR
                                                                                                AND N.CDGRUPPROD = V_CDGRUPPROD) A
                                                                                         ON C.CDARVPROD LIKE A.CDPRODUTO||'%'
                                                                 WHERE A.CDFILISUBGR = P_CDFILISUBGR
                                                                   AND A.CDGRUPPROD = V_CDGRUPPROD
                                                                 ORDER BY B.CDARVPROD) AN ON P.CDPRODUTO = AN.CDPRODUTO
                                                    INNER JOIN SUBGRPRODFIL SG ON AN.CDFILISUBGR = SG.CDFILISUBGR
                                                                              AND AN.CDGRUPPROD = SG.CDGRUPPROD
                                                                              AND AN.CDSUBGRPROD = SG.CDSUBGRPROD
                              WHERE R.CDFILIMOVIEST = P_CDFILIAL
                                AND R.NRRELATMOVI = V_NRMOVIESTQ
                                AND TRUNC(R.DTLANCMOVIEST) BETWEEN P_DTINICIAL AND P_DTFINAL
                                AND SG.CDGRUPPROD = V_CDGRUPPROD
                                AND SG.CDFILISUBGR = P_CDFILISUBGR
                                AND R.IDTIPOMOVIEST = '1'
                              GROUP BY AN.CDGRUPPROD, AN.CDSUBGRPROD, TRUNC(DTLANCMOVIEST)
                              ORDER BY DTLANCMOVIEST, AN.CDSUBGRPROD, AN.CDGRUPPROD) LOOP

               NOVO_CODIGO('GESINVENTARIOROP', V_NRSEQINVENTROP);

               INSERT INTO INVENTARIOROP (NRFILIALROP, NRINVENTARIOROP, CDFILIAL, CDGRUPPROD, CDSUBGRPROD,
                                          IDTPLANCROP, VRITEMLANCROP, CDFILIALCENT, DTINVENTARIO, DTLANCAMENT,
                                          QTESTDIACON)
                    VALUES (P_NRROPFILIAL, V_NRSEQINVENTROP, P_CDFILIAL, C_AJUSTE.CDGRUPPROD, C_AJUSTE.CDSUBGRPROD,
                            'AJUSTE', C_AJUSTE.VRDIFECUST, V_CDFILCENTPME, C_AJUSTE.DTLANCMOVIEST, SYSDATE,
                            C_AJUSTE.QTLANCAMENTO);
            END LOOP;
         END IF;
      END IF;
 
      DELETE FROM RELAT_MOVIEST
            WHERE CDFILIMOVIEST = P_CDFILIAL
              AND NRRELATMOVI = V_NRMOVIESTQ;
   END IF;
END;
/